---
title: <span class="badge object-type-enum"></span> BucketAggregationType
---
# <span class="badge object-type-enum"></span> BucketAggregationType

## Definition

```python
class BucketAggregationType(enum.StrEnum):
    TERMS = "terms"
    FILTERS = "filters"
    GEOHASH_GRID = "geohash_grid"
    DATE_HISTOGRAM = "date_histogram"
    HISTOGRAM = "histogram"
    NESTED = "nested"
```
